@@ -28,6 +28,7 @@
 #include "utils.h"
 #include "cleanup-funcs.h"
 #include "classic.h"
+#include "mount-opt.h"
 // XXX: for smaller patch, this should be in utils.h later
 #include "user-support.h"
 
@@ -86,11 +87,12 @@ static void sc_quirk_mkdir_bind(const char *src_dir, const char *dest_dir,
 	flags |= MS_BIND;
 	debug("creating empty directory at %s", dest_dir);
 	mkpath(dest_dir);
-	debug("bind mounting %s -> %s with flags %#x", src_dir, dest_dir,
-	      flags);
+	const char *flags_str = sc_mount_opt2str(flags);
+	debug("performing operation: mount %s %s -o %s", src_dir, dest_dir,
+	      flags_str);
 	if (mount(src_dir, dest_dir, NULL, flags, NULL) != 0) {
-		die("cannot bind mount %s -> %s with flags %#x", src_dir,
-		    dest_dir, flags);
+		die("cannot perform operation: mount %s %s -o %s", src_dir,
+		    dest_dir, flags_str);
 	}
 }
 
@@ -176,9 +178,12 @@ void sc_setup_quirks()
 	if (mkdtemp(snapd_tmp) == 0) {
 		die("cannot create temporary directory for /var/lib/snapd mount point");
 	}
+	debug("performing operation: mount --move %s %s", "/var/lib/snapd",
+	      snapd_tmp);
 	if (mount("/var/lib/snapd", snapd_tmp, NULL, MS_MOVE, NULL)
 	    != 0) {
-		die("cannot move /var/lib/snapd to %s", snapd_tmp);
+		die("cannot perform operation: mount --move %s %s",
+		    "/var/lib/snapd", snapd_tmp);
 	}
 	// now let's make /var/lib the vanilla /var/lib from the core snap
 	char buf[PATH_MAX];
@@ -188,15 +193,20 @@ void sc_setup_quirks()
 				       MS_RDONLY | MS_REC | MS_SLAVE | MS_NODEV
 				       | MS_NOSUID);
 	// now let's move /var/lib/snapd (that was originally there) back
+	debug("performing operation: umount %s", "/var/lib/snapd");
 	if (umount("/var/lib/snapd") != 0) {
-		die("cannot unmount /var/lib/snapd");
+		die("cannot perform operation: umount %s", "/var/lib/snapd");
 	}
+	debug("performing operation: mount --move %s %s", snapd_tmp,
+	      "/var/lib/snapd");
 	if (mount(snapd_tmp, "/var/lib/snapd", NULL, MS_MOVE, NULL)
 	    != 0) {
-		die("cannot move %s to /var/lib/snapd", snapd_tmp);
+		die("cannot perform operation: mount --move %s %s", snapd_tmp,
+		    "/var/lib/snapd");
 	}
+	debug("performing operation: rmdir %s", snapd_tmp);
 	if (rmdir(snapd_tmp) != 0) {
-		die("cannot remove %s", snapd_tmp);
+		die("cannot perform operation: rmdir %s", snapd_tmp);
 	}
 	// We are now ready to apply any quirks that relate to /var/lib
 	sc_setup_lxd_quirk();
